#
# spec file for package python-oslotest
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslotest
Version:        5.0.0
Release:        1.1
Summary:        OpenStack test framework
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslotest
Source0:        https://files.pythonhosted.org/packages/source/o/oslotest/oslotest-5.0.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-debtcollector
BuildRequires:  python3-fixtures >= 3.0.0
BuildRequires:  python3-pbr
BuildRequires:  python3-python-subunit >= 1.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testtools >= 2.2.0
BuildArch:      noarch

%description
The Oslo Test framework provides common fixtures, support for debugging, and
better support for mocking results.

%package -n python3-oslotest
Summary:        OpenStack test framework
Requires:       python3-debtcollector
Requires:       python3-fixtures >= 3.0.0
# NOTE: python-os-client-config is only needed for functional testing
# Requires:       python3-os-client-config
Requires:       python3-python-subunit >= 1.0.0
Requires:       python3-stestr
Requires:       python3-testtools >= 2.2.0

%description -n python3-oslotest
The Oslo Test framework provides common fixtures, support for debugging, and
better support for mocking results.

This package contains the Python 3.x module.

%prep
%autosetup -p1 -n oslotest-%{version}
%py_req_cleanup

%build
%py3_build

%install
%py3_install

%check
%{openstack_stestr_run}

%files -n python3-oslotest
%license LICENSE
%doc ChangeLog README.rst
%{_bindir}/oslo_debug_helper
%{_bindir}/oslo_run_cross_tests
%{_bindir}/oslo_run_pre_release_tests
%{python3_sitelib}/oslotest
%{python3_sitelib}/oslotest*egg-info

%changelog
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 5.0.0
  - pre-commit: Bump versions
  - Drop python3.6/3.7 support in testing runtime
  - Update python classifier in setup.cfg
  - Replace find_module function
  - Cleanup py27 support
  - Moves supported python runtimes from version 3.8 to 3.10
  - tox: Bump minimum to tox 4.x
  - Update CI to use unversioned jobs template
  - Remove unnecessary unicode prefixes
  - Remove usage of six
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Fix formatting of release list
  - Bump hacking
* Fri Aug 12 2022 Dirk Müller <dmueller@suse.com>
- drop unnecessary mock dependency
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- remove unnecessary dependencies
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 4.5.0
  - setup.cfg: Replace dashes with underscores
  - Move flake8 as a pre-commit local target.
  - Use TOX_CONSTRAINTS_FILE
  - Document unit of measure for OS_TEST_TIMEOUT
  - Adding pre-commit
  - Add Python3 wallaby unit tests
  - Dropping lower constraints testing
  - Update master for stable/victoria
  - Use py3 as the default runtime for tox
  - Remove lower-constraints remnants
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.4.1
  - Align contributing doc with oslo's policy
  - Add release notes links to doc index
  - Add py38 package metadata
  - Bump default tox env from py37 to py38
  - Update master for stable/ussuri
  - Revert "Revert "Switch to unittest.mock from mock""
  - Stop to use the __future__ module.
  - Switch to newer openstackdocstheme and reno versions
  - Add Python3 victoria unit tests
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.2.0
  - Update master for stable/train
  - Remove 'oslotest.functional'
  - Remove os-client-config and debtcollector
  - remove outdated header
  - gitignore: Ignore reno artefacts
  - tools: Default to Python 3
  - Switch to Ussuri jobs
  - Switch to unittest.mock from mock
  - tox: Trivial cleanup
  - Remove stestr from requirements.txt
  - Invoke correct python version in shell scripts
  - Remove 'oslotest.moxstubout' module
  - Revert "Switch to unittest.mock from mock"
  - [ussuri][goal] Drop python 2.7 support and testing
  - trivial: Cleanup of doc config file
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- removed 0001-Stop-testing-mock-functionality.patch
- update to version 3.8.1
  - Stop testing mock functionality
  - Add Python 3 Train unit tests
  - Dropping the py35 testing
  - OpenDev Migration Patch
  - Replace git.openstack.org URLs with opendev.org URLs
  - Sync Sphinx requirement
  - Update master for stable/stein
  - Replace openstack.org git:// URLs with https://
* Mon Aug  5 2019 cloud-devel@suse.de
- added 0001-Stop-testing-mock-functionality.patch
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.7.1
  - Add release note link in README
  - Add DEFAULT_TIMEOUT and TIMEOUT_SCALING_FACTOR
  - Change python3.5 job to python3.7 job on Stein+
  - Change openstack-dev to openstack-discuss
  - Update hacking version
  - Update reno for stable/rocky
  - Fix requirements check ci in oslotest
  - Fix nits in timeout change
  - add python 3.6 unit test job
  - Title underline too long
  - import zuul job settings from project-config
  - Use templates for cover and lower-constraints
  - Don't quote {posargs} in tox.ini
* Thu Sep 20 2018 cloud-devel@suse.de
- update to version 3.6.0
  - Switch to using stestr
  - Fix requirements
  - fix tox python3 overrides
  - Deprecate MoxStubout class
  - mock: Perform patch's autospec checks on __enter__
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.4.2
  - set default python to python3
  - Update reno for stable/queens
  - Update links in README
  - make the CaptureOutput fixture easier to control
  - Trivial: Update pypi url to new url
  - mock: Apply autospec to a mock's return_value
  - mock: Properly patch mock.MagicMock
  - Updated from global requirements
  - add lower-constraints job
  - mock: Fixes mock.patch.multiple autospec
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.2.0
  - Remove -U from pip install
  - Remove setting of version/release from releasenotes
  - Avoid tox_install.sh for constraints support
  - Remove oslotest.mockpatch
  - Adds mock autospec fixture
  - Updated from global requirements
* Thu Nov 23 2017 cloud-devel@suse.de
- update to version 2.18.1
  - Update reno for stable/pike
  - Use assertIsNone(...) instead of assertIs(None,...)
  - Updated from global requirements
  - Deprecate oslotest.functional
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.17.0
  - Remove pbr warnerrors in favor of sphinx check
  - Trivial fix style in document
  - Using fixtures instead of deprecated mockpatch module
  - rearrange content to fit the new standard layout
  - Update URLs in documents according to document migration
  - [Fix gate]Update test requirement
  - Update reno for stable/ocata
  - Remove support for py34
  - Updated from global requirements
  - Switch from oslosphinx to openstackdocstheme
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 2.13.0:
  - Add Constraints support
  - Updated from global requirements
  - Show team and repo badges on README
  - Changed the home-page link
  - Add reno for release notes management
  - Remove testscenarios from requirements
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 2.10.0
  * A DisableModules fixture that removes modules from path
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to 2.8.0:
  * Import mock so that it works on Python 3.x
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Add Python 3.5 classifier and venv
* Mon Jul  4 2016 tbechtold@suse.com
- update to 2.6.0:
  * Updated from global requirements
  * Remove mockpatch re-implementations
* Sun Jun 19 2016 dmueller@suse.com
- update to 2.4.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
  * Add some gitignore files
  * move unit tests into the oslotest package
  * Updated from global requirements
  * Hack to get back stopall cleanup behavior feature
  * Fix misspelling
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
* Thu Mar  3 2016 tbechtold@suse.com
- update to 2.0.0:
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * mockpatch: deprecate in favor of native fixtures
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
  * Fix coverage configuration and execution
  * Updated from global requirements
  * Add documentation about using oslo_debug_helper
  * add oslo.config a test requirement
  * clean up readme and doc title
  * clean up toctree
  * auto-generate API documentation
  * Fix the home-page with Oslotest wikipage
  * Fixup docstrings
  * Updated from global requirements
  * Updated from global requirements
- Switch to .spec from rpm-packaging upstream project
* Fri Aug  7 2015 dmueller@suse.com
- update to 1.10.0:
  * Allow TRACE and integer logging levels for 'OS_DEBUG'
  * Updated from global requirements
* Tue Jul 14 2015 dmueller@suse.com
- update to 1.9.0:
  * Fix use of mock
  * Add documentation for cross-project unit testing
  * Updated from global requirements
  * Fix build break with Fixtures 1.3
  * Updated from global requirements
* Wed Jun 24 2015 tbechtold@suse.com
- update to 1.8.0:
  * Updated from global requirements
  * Allow ``OS_DEBUG`` environment variable to specify log level
  * Updated from global requirements
  * always rebuild cross-test venv
  * Add CreateFileWithContent fixture
  * Create ConfigureLogging fixture
  * Create CaptureOutput fixture
  * Create Timeout wrapper fixture
  * Document the mock attribute for mockpatch
* Mon Jun 22 2015 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Fix argument handling in oslo_run_cross_tests
  * Add class to deal with clouds.yaml support
  * Remove unneeded runtime pbr dep
  * Updated from global requirements
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Do not sync run_cross_tests.sh
  * Remove unused discover dependency
  * Uncap library requirements for liberty
  * Cleanup README.rst and setup.cfg
  * mockpatch: factorize code
  * Update to latest hacking
  * Updated from global requirements
  * mockpatch: fix a potential race condition
- Adjust Requires according to requirements.txt
* Tue Apr  7 2015 bwiedemann@suse.com
- update to 1.5.1
* Tue Feb 24 2015 tbechtold@suse.com
- update to 1.5.0:
  * Restore missing module for pre-release test script
  * Updated from global requirements
  * Set a higher default for maxDiff
  * Move the script for running pre-releases into oslotest
  * Update docs for new script name
  * Publish cross-test runner as part of oslotest
  * Fix for mktemp failure on osx
  * Activate pep8 check that _ is imported
  * Workflow documentation is now in infra-manual
  * Fix the URL for reporting bugs in the README
  * Updated from global requirements
  * Add pbr to installation requirements
  * Clean up the docs for oslo_debug_helper
- Adjust Requires according to requirements.txt
- Add oslo_run_cross_tests oslo_run_pre_release_tests to /usr/bin/
* Tue Oct 28 2014 dmueller@suse.com
- update to 1.2.0:
  * Updated from global requirements
  * Set install_command in tox to avoid pre-releases
  * Add an extra parameter for test directory in debugger script
  * Handle tempfile content encoding
  * Work toward Python 3.4 support and testing
  * Add links to best practices video and etherpad
  * Updated from global requirements
  * Drop .sh extension from oslo_debug_helper.sh
  * Add history/changelog to docs
  * fix typo and formatting in contributing docs
* Sat Sep 27 2014 dmueller@suse.com
- update to 1.1.0:
  * no change compared to 1.1.0.0a2
* Tue Sep 16 2014 dmueller@suse.com
- update to 1.1.0.0a2:
  * Add fixture for mock.patch.multiple
  * Ensure that mock.patch.stopall is called last
  * Remove differences between Python 2.x and 3.x versions
  * Require six
  * Add documentation for running oslo_debug_heler.sh
  * Restructure oslotest docs
  * Add pdb support to tox with debug helper shell script
  * Updated from global requirements
  * Cleaning up index.rst file
  * Add known issue about time.time mocking
  * Updated from global requirements
  * Add API documentation
  * Moving to use the mock module found in Python3
* Wed Sep  3 2014 dmueller@suse.com
- add drop-mox-dependency.diff
* Tue Aug 26 2014 dmueller@suse.com
- update to 1.1.0.0a1:
  * Update to hacking 0.9.2
  * Cleanup mock patches on BaseTestCase tearDown(
  * Add unit test for olsotest base class
  * fix .gitreview after rename
  * Sync new sphinx requirement spec
  * Set log level to default value
  * Updated from global requirements
  * Update cross-test directions
  * Update project name in doc build
* Wed Apr  2 2014 speilicke@suse.com
- Update to version 1.0.0:
  * Import run_cross_tests.sh from oslo-incubator
  * Fix up documentation files
  * Fake logger as instance attribute
  * Require testrepository and other tools at runtime
  * Updated from global requirements
  * Add tool to run cross-project tests
- Fix dependencies
- Use testrepository to run tests
* Thu Mar 27 2014 cfarrell@suse.com
- license update: Apache-2.0
  See LICENSE
* Mon Mar  3 2014 bwiedemann@suse.com
- initial package using
  py2pack generate -t opensuse.spec -f python-oslotest.spec oslotest
